import { Document, Page, Text, View } from "@react-pdf/renderer";
import { TransactionListType } from "../Types/Types";
import { colors } from "../../styles";
import moment from "moment";

type props = {
  transactions: TransactionListType;
  filter: "Day" | "Month";
};

export default function TransactionReportPDF(props: props) {
  const todayStartOfDay = moment().startOf("day").format("MM-DD-YYYY hh:mm A");
  const todayEndOfDay = moment().endOf("day").format("MM-DD-YYYY hh:mm A");
  const thisMonthStart = moment().startOf("month").format("MM-DD-YYYY hh:mm A");
  const thisMonthEnd = moment().endOf("month").format("MM-DD-YYYY hh:mm A");
  function get_equipment_count_today() {
    let n = 0;
    props.transactions
      .filter((transaction) =>
        moment(transaction.timestamp, "MM-DD-YYYY hh:mm A").isBetween(
          todayStartOfDay,
          todayEndOfDay
        )
      )
      .forEach((transaction) => (n += transaction.equipments.length));
    return n;
  }
  function get_equipment_count_thismonth() {
    let n = 0;
    props.transactions
      .filter((transaction) =>
        moment(transaction.timestamp, "MM-DD-YYYY hh:mm A").isBetween(
          thisMonthStart,
          thisMonthEnd
        )
      )
      .forEach((transaction) => (n += transaction.equipments.length));
    return n;
  }
  function get_transactions_today() {
    return props.transactions.filter((transaction) =>
      moment(transaction.timestamp, "MM-DD-YYYY hh:mm A").isBetween(
        todayStartOfDay,
        todayEndOfDay
      )
    );
  }
  function get_transactions_thismonth() {
    return props.transactions.filter((transaction) =>
      moment(transaction.timestamp, "MM-DD-YYYY hh:mm A").isBetween(
        thisMonthStart,
        thisMonthEnd
      )
    );
  }
  return (
    <Document>
      <Page size={"A4"}>
        <Text
          style={{
            color: colors.font_dark,
            fontSize: 16,
            alignSelf: "center",
            justifyContent: "center",
          }}
        >
          Daily Transaction Report
        </Text>
        <View
          style={{
            alignSelf: "center",
            justifyContent: "center",
            width: "512px",
            backgroundColor: colors.header_color,
            borderRadius: 16,
            margin: "8px",
            padding: "8px",
          }}
        >
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Equipments Processed: {get_equipment_count_today()}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Transactions: {get_transactions_today().length}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Rejected Transactions:{" "}
            {
              get_transactions_today().filter(
                (transaction) => transaction.transaction_status == "Rejected"
              ).length
            }
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Rejected Transactions:{" "}
            {
              get_transactions_today().filter(
                (transaction) => transaction.transaction_status == "Rejected"
              ).length
            }
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Finalized Transactions:{" "}
            {
              get_transactions_today().filter(
                (transaction) => transaction.transaction_status == "Finalized"
              ).length
            }
          </Text>
        </View>
        <Text
          style={{
            color: colors.font_dark,
            fontSize: 16,
            alignSelf: "center",
            justifyContent: "center",
          }}
        >
          Monthly Transaction Report
        </Text>
        <View
          style={{
            alignSelf: "center",
            justifyContent: "center",
            width: "512px",
            backgroundColor: colors.header_color,
            borderRadius: 16,
            margin: "8px",
            padding: "8px",
          }}
        >
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Equipments Processed: {get_equipment_count_thismonth()}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Transactions: {get_transactions_thismonth().length}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Rejected Transactions:{" "}
            {
              get_transactions_thismonth().filter(
                (transaction) => transaction.transaction_status == "Rejected"
              ).length
            }
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Finalized Transactions:{" "}
            {
              get_transactions_thismonth().filter(
                (transaction) => transaction.transaction_status == "Finalized"
              ).length
            }
          </Text>
        </View>
      </Page>
    </Document>
  );
}
